if not SimpleTankFrames then return end
local addon = SimpleTankFrames

local frame = CreateFrame("Frame", nil, InterfaceOptionsFramePanelContainer)
frame.name = "SimpleTankFrames"
frame:Hide()

local function newCheckbox(label, onClick)
	local check = CreateFrame("CheckButton", nil, frame)
	check:SetWidth(26)
	check:SetHeight(26)
	check:SetHitRectInsets(0, -100, 0, 0)
	check:SetNormalTexture("Interface\\Buttons\\UI-CheckBox-Up")
	check:SetPushedTexture("Interface\\Buttons\\UI-CheckBox-Down")
	check:SetHighlightTexture("Interface\\Buttons\\UI-CheckBox-Highlight")
	check:SetDisabledCheckedTexture("Interface\\Buttons\\UI-CheckBox-Check-Disabled")
	check:SetCheckedTexture("Interface\\Buttons\\UI-CheckBox-Check")
	check:SetScript("OnClick", function(self)
		PlaySound(self:GetChecked() and "igMainMenuOptionCheckBoxOn" or "igMainMenuOptionCheckBoxOff")
		onClick(self, self:GetChecked() and true or false)
	end)
	check:SetScript("OnEnter", onControlEnter)
	check:SetScript("OnLeave", onControlLeave)
	check.label = label
	check.description = description
	local fs = check:CreateFontString(nil, "ARTWORK", "GameFontHighlight")
	fs:SetPoint("LEFT", check, "RIGHT", 0, 1)
	fs:SetPoint("RIGHT", frame, "RIGHT", 0, 0)
	fs:SetJustifyH("LEFT")
	fs:SetText(label)
	fs:SetWidth(200)
	return check
end

frame:SetScript("OnShow", function(frame)
	local title = frame:CreateFontString(nil, "ARTWORK", "GameFontNormalLarge")
	title:SetPoint("TOPLEFT", 16, -16)
	title:SetText("SimpleTankFrames")

	local subtitle = frame:CreateFontString(nil, "ARTWORK", "GameFontHighlight")
	subtitle:SetPoint("TOPLEFT", title, "BOTTOMLEFT", 0, -8)
	subtitle:SetWidth(frame:GetWidth() - 48)
	subtitle:SetJustifyH("LEFT")
	subtitle:SetJustifyV("TOP")
	subtitle:SetText("oRA2-style main tank frames populated by the sorted tank list from oRA3.\n\n|cffff4411Note that NONE of these settings apply until you reload your interface or relog, simply because I am a lazy bastard.|r")

	local lockFunc = function(self, value) addon.db.lock = value end
	local lock = newCheckbox("Lock", lockFunc)
	lock:SetChecked(addon.db.lock)
	lock:SetPoint("TOPLEFT", subtitle, "BOTTOMLEFT", -2, -8)

	local percentFunc = function(self, value) addon.db.showHp = value end
	local percent = newCheckbox("Hitpoints", percentFunc)
	percent:SetChecked(addon.db.showHp)
	percent:SetPoint("TOPLEFT", lock, "BOTTOMLEFT", 0, -4)

	local highlightFunc = function(self, value) addon.db.highlight = value end
	local highlight = newCheckbox("Target highlight", highlightFunc)
	highlight:SetChecked(addon.db.highlight)
	highlight:SetPoint("TOPLEFT", percent, "BOTTOMLEFT", 0, -4)

	local media = LibStub and LibStub("LibSharedMedia-3.0", true)
	local texture = nil
	if media then
		texture = frame:CreateFontString(nil, "OVERLAY", "GameFontNormal")
		texture:SetPoint("TOPLEFT", highlight, "BOTTOMLEFT", 8, -16)
		texture:SetJustifyH("LEFT")
		texture:SetHeight(18)
		texture:SetText("Texture")
		local dropdown = CreateFrame("Frame", "SimpleTankFrameTextureDropdown", frame, "UIDropDownMenuTemplate")
		dropdown:SetPoint("TOPLEFT", texture, "TOPRIGHT", 16, 3)
		local function itemOnClick(self)
			local selected = self.value
			local actualTexture = media:Fetch("statusbar", selected)
			addon.db.bar = actualTexture
			UIDropDownMenu_SetSelectedValue(dropdown, selected)
		end
		UIDropDownMenu_Initialize(dropdown, function()
			local info = UIDropDownMenu_CreateInfo()
			for name, tex in pairs(media:HashTable("statusbar")) do
				info.text = name
				info.value = name
				info.func = itemOnClick
				info.checked = tex == addon.db.bar
				UIDropDownMenu_AddButton(info)
			end
		end)
		UIDropDownMenu_SetSelectedValue(dropdown, addon.db.bar)
		UIDropDownMenu_SetWidth(dropdown, 160)
		UIDropDownMenu_JustifyText(dropdown, "LEFT")
	end

	local sliderLabel = frame:CreateFontString(nil, "ARTWORK", "GameFontNormal")
	sliderLabel:SetJustifyH("LEFT")
	sliderLabel:SetText("Scale")
	sliderLabel:SetPoint("TOPLEFT", texture or highlight, "BOTTOMLEFT", 8, -24)

	local sliderValue = frame:CreateFontString(nil, "ARTWORK", "GameFontHighlightSmall")
	sliderValue:SetJustifyH("LEFT")
	sliderValue:SetText(addon.db.scale)

	local slider = CreateFrame("Slider", nil, frame)
	slider:SetHeight(17)
	slider:SetWidth(144)
	slider:SetOrientation("HORIZONTAL")
	slider:SetThumbTexture("Interface\\Buttons\\UI-SliderBar-Button-Horizontal")
	slider:SetBackdrop({
		bgFile = "Interface\\Buttons\\UI-SliderBar-Background",
		edgeFile = "Interface\\Buttons\\UI-SliderBar-Border",
		edgeSize = 8, tile = true, tileSize = 8,
		insets = {left = 3, right = 3, top = 6, bottom = 6}
	})
	slider:SetMinMaxValues(0.1, 1)
	slider:SetValue(addon.db.scale)
	slider:SetValueStep(0.05)
	slider:SetScript("OnValueChanged", function(self, value)
		addon.db.scale = value
		sliderValue:SetText(value)
	end)
	slider:SetPoint("LEFT", sliderLabel, "RIGHT", 36, 0)
	sliderValue:SetPoint("LEFT", slider, "RIGHT", 8, 0)

	frame:SetScript("OnShow", nil)
end)
InterfaceOptions_AddCategory(frame)

